django-infuse
=============

Series of Class based mixins.  Requires Django 1.4s use of PermissionDenied exception. 

Installation
------------

    pip install django-infuse
    
Currently Supported Mixins
--------------------------

* Permission Required
* Staff Required
* Super User required
* Login Required
* Group Required

